@@ -4,7 +4,8 @@ require File.expand_path(File.dirname(__FILE__) + "/client_api/spec_helper")
 
 describe Braintree::Customer do
   describe "self.all" do
-    it "gets more than a page of customers" do
+    #Disabling test until we have a more stable CI
+    xit "gets more than a page of customers" do
       customers = Braintree::Customer.all
       expect(customers.maximum_size).to be > 100
 
@@ -38,6 +39,7 @@ describe Braintree::Customer do
         :company => "Microsoft",
         :email => "bill@microsoft.com",
         :phone => "312.555.1234",
+        :international_phone => {:country_code => "1", :national_number => "3121234567"},
         :fax => "614.555.5678",
         :website => "www.microsoft.com",
         :tax_identifiers => [{:country_code => "US", :identifier => "987654321"}],
@@ -49,6 +51,8 @@ describe Braintree::Customer do
       expect(result.customer.company).to eq("Microsoft")
       expect(result.customer.email).to eq("bill@microsoft.com")
       expect(result.customer.phone).to eq("312.555.1234")
+      expect(result.customer.international_phone[:country_code]).to eq("1")
+      expect(result.customer.international_phone[:national_number]).to eq("3121234567")
       expect(result.customer.fax).to eq("614.555.5678")
       expect(result.customer.website).to eq("www.microsoft.com")
       expect(result.customer.created_at.between?(Time.now - 10, Time.now)).to eq(true)
@@ -617,7 +621,7 @@ describe Braintree::Customer do
           :credit_card => {
             :options => {
               :verify_card => true,
-              :verification_merchant_account_id => SpecHelper::HiperBRLMerchantAccountId,
+              :verification_merchant_account_id => SpecHelper::CardProcessorBRLMerchantAccountId,
               :verification_account_type => "debit",
             }
           },
@@ -987,18 +991,19 @@ describe Braintree::Customer do
       expect(found_customer.apple_pay_cards).not_to be_nil
       apple_pay_card = found_customer.apple_pay_cards.first
       expect(apple_pay_card).to be_a Braintree::ApplePayCard
-      expect(apple_pay_card.token).not_to be_nil
-      expect(apple_pay_card.expiration_year).not_to be_nil
-      expect(apple_pay_card.payment_instrument_name).to eq("AmEx 41002")
       expect(apple_pay_card.commercial).not_to be_nil
       expect(apple_pay_card.country_of_issuance).not_to be_nil
       expect(apple_pay_card.debit).not_to be_nil
       expect(apple_pay_card.durbin_regulated).not_to be_nil
+      expect(apple_pay_card.expiration_year).not_to be_nil
       expect(apple_pay_card.healthcare).not_to be_nil
       expect(apple_pay_card.issuing_bank).not_to be_nil
+      expect(apple_pay_card.payment_instrument_name).to eq("AmEx 41002")
       expect(apple_pay_card.payroll).not_to be_nil
       expect(apple_pay_card.prepaid).not_to be_nil
+      expect(apple_pay_card.prepaid_reloadable).not_to be_nil
       expect(apple_pay_card.product_id).not_to be_nil
+      expect(apple_pay_card.token).not_to be_nil
     end
 
     it "returns associated google pay proxy cards" do
@@ -1012,18 +1017,19 @@ describe Braintree::Customer do
       expect(found_customer.payment_methods.size).to eq(1)
       google_pay_card = found_customer.google_pay_cards.first
       expect(google_pay_card).to be_a Braintree::GooglePayCard
-      expect(google_pay_card.token).not_to be_nil
-      expect(google_pay_card.expiration_year).not_to be_nil
-      expect(google_pay_card.is_network_tokenized?).to eq(false)
       expect(google_pay_card.commercial).not_to be_nil
       expect(google_pay_card.country_of_issuance).not_to be_nil
       expect(google_pay_card.debit).not_to be_nil
       expect(google_pay_card.durbin_regulated).not_to be_nil
+      expect(google_pay_card.expiration_year).not_to be_nil
       expect(google_pay_card.healthcare).not_to be_nil
+      expect(google_pay_card.is_network_tokenized?).to eq(false)
       expect(google_pay_card.issuing_bank).not_to be_nil
       expect(google_pay_card.payroll).not_to be_nil
       expect(google_pay_card.prepaid).not_to be_nil
+      expect(google_pay_card.prepaid_reloadable).not_to be_nil
       expect(google_pay_card.product_id).not_to be_nil
+      expect(google_pay_card.token).not_to be_nil
     end
 
     it "returns associated google pay network tokens" do
@@ -1048,6 +1054,7 @@ describe Braintree::Customer do
       expect(google_pay_card.issuing_bank).not_to be_nil
       expect(google_pay_card.payroll).not_to be_nil
       expect(google_pay_card.prepaid).not_to be_nil
+      expect(google_pay_card.prepaid_reloadable).not_to be_nil
       expect(google_pay_card.product_id).not_to be_nil
     end
 
@@ -1193,6 +1200,7 @@ describe Braintree::Customer do
         customer.id,
         :first_name => "Mr. Joe",
         :last_name => "Super Cool",
+        :international_phone => {:country_code => "1", :national_number => "3121234567"},
         :custom_fields => {
           :store_me => "a value"
         },
@@ -1201,6 +1209,8 @@ describe Braintree::Customer do
       expect(result.customer.id).to eq(customer.id)
       expect(result.customer.first_name).to eq("Mr. Joe")
       expect(result.customer.last_name).to eq("Super Cool")
+      expect(result.customer.international_phone[:country_code]).to eq("1")
+      expect(result.customer.international_phone[:national_number]).to eq("3121234567")
       expect(result.customer.custom_fields[:store_me]).to eq("a value")
     end
 
@@ -1225,6 +1235,27 @@ describe Braintree::Customer do
       expect(result.errors.for(:customer).for(:credit_card).on(:number)[0].message).to eq("Duplicate card exists in the vault.")
     end
 
+    it "does not update customer with duplicate payment method if fail_on_payment_method_for_customer option set" do
+      customer = Braintree::Customer.create!(
+        :credit_card => {
+          :number => 4111111111111111,
+          :expiration_date => "05/2010",
+        },
+      )
+      result = Braintree::Customer.update(
+        customer.id,
+        :credit_card => {
+          :number => 4111111111111111,
+          :expiration_date => "05/2010",
+          :options=> {
+            :fail_on_duplicate_payment_method_for_customer => true
+          }
+        },
+      )
+      expect(result.success?).to eq(false)
+      expect(result.errors.for(:customer).for(:credit_card).on(:number)[0].message).to eq("Duplicate card exists in the vault for the customer.")
+    end
+
     it "updates the default payment method" do
       customer = Braintree::Customer.create!(
         :first_name => "Joe",
@@ -1658,7 +1689,7 @@ describe Braintree::Customer do
             :expiration_date => "06/2013",
             :options => {
               :verify_card => true,
-              :verification_merchant_account_id => SpecHelper::HiperBRLMerchantAccountId,
+              :verification_merchant_account_id => SpecHelper::CardProcessorBRLMerchantAccountId,
               :verification_account_type => "debit",
             },
           },
@@ -1884,4 +1915,17 @@ describe Braintree::Customer do
       end
     end
   end
+
+  it "returns prepaid_reloadable from VisaCheckoutCard" do
+    result = Braintree::Customer.create(
+      :payment_method_nonce => Braintree::Test::Nonce::VisaCheckoutVisa,
+    )
+    expect(result.success?).to eq(true)
+
+    found_customer = Braintree::Customer.find(result.customer.id)
+    expect(found_customer.visa_checkout_cards).not_to be_nil
+    visa_checkout_card = found_customer.visa_checkout_cards.first
+    expect(visa_checkout_card).to be_a Braintree::VisaCheckoutCard
+    expect(visa_checkout_card.prepaid_reloadable).not_to be_nil
+  end
 end
